

=============================
Convolutional Neural Networks
=============================

Papers
------

* `A guide to convolution arithmetic for deep learning <https://arxiv.org/abs/1603.07285>`_

Codes
-----

* `tensorflow example of visualizing features from a convnet <https://github.com/kvfrans/feature-visualization>`_
* `VGG Convolutional Neural Networks Practical <http://www.robots.ox.ac.uk/~vgg/practicals/cnn/>`_
* `Convolutional Neural Networks (LeNet) <http://deeplearning.net/tutorial/lenet.html>`_ - Theano DL
* `CS231n Convolutional Neural Networks for Visual Recognition <https://github.com/MyHumbleSelf/cs231n>`_, numpy implementation


Blogs
-----

* `CS231n Convolutional Neural Networks for Visual Recognition <http://cs231n.github.io/convolutional-networks/>`_
* `Convolutional Neural Networks (LeNet) <http://deeplearning.net/tutorial/lenet.html>`_  - Theano DL
* `从入门到精通：卷积神经网络初学者指南 - 机器之心 <http://synchuman.baijia.baidu.com/article/566475>`_
* `卷积神经网络的数学推导 <http://tech.youmi.net/2016/07/163347168.html>`_
* `Visualizing Features from a Convolutional Neural Network <http://kvfrans.com/visualizing-features-from-a-convolutional-neural-network/>`_
* `Convolutional Neural Networks backpropagation: from intuition to derivation <https://grzegorzgwardys.wordpress.com/2016/04/22/8/>`_
* `神经网络反向传播的数学原理 <https://zhuanlan.zhihu.com/p/22473137>`_
* `An Intuitive Explanation of Convolutional Neural Networks <https://ujjwalkarn.me/
  2016/08/11/intuitive-explanation-convnets/>`_  and `神经网络的直观解释 <http://www.h
  ackcv.com/index.php/archives/104/?hmsr=toutiao.io&utm_medium=toutiao.io&utm_source
  =toutiao.io>`_
* `Deep learning：五十一(CNN的反向求导及练习) <http://www.cnblogs.com/tornadomeet/p/3468450.html>`_
* `Deep Learning论文笔记之（四）CNN卷积神经网络推导和实现 <http://blog.csdn.net/zouxy09/article/details/9993371>`_
